# FINAM-mHM component

FINAM component for the mesoscale Hydrological Model - [mHM](https://mhm-ufz.org/)

<a href="https://finam.pages.ufz.de/finam-mhm/" title="FINAM-mHM homepage" target="_blank">
  <img width="300" src="https://git.ufz.de/FINAM/finam-mhm/-/raw/main/docs/source/_static/logo_large.svg" />
</a>

## Installation

```shell
$ pip install finam-mhm
```

## Resources

* FINAM-mHM [documentation](https://finam.pages.ufz.de/finam-mhm/)
* FINAM-mHM [source code](https://git.ufz.de/FINAM/finam-mhm)
* FINAM [homepage](https://finam.pages.ufz.de)
* FINAM [documentation](https://finam.pages.ufz.de/finam/)
* FINAM [source code](https://git.ufz.de/FINAM/finam)
* FINAM [GitLab group](https://git.ufz.de/FINAM), containing further related projects

## License

LGPLv3 (c) 2021-2025 CHS- and FINAM-Developers from Helmholtz-Zentrum für Umweltforschung GmbH - UFZ. All rights reserved.
